"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _HostRequestStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _HostRequestStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_HostRequestStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    HOST_REQUEST_STATUS_PENDING: _HostRequestStatus.ValueType  # 0
    HOST_REQUEST_STATUS_ACCEPTED: _HostRequestStatus.ValueType  # 1
    HOST_REQUEST_STATUS_REJECTED: _HostRequestStatus.ValueType  # 2
    HOST_REQUEST_STATUS_CONFIRMED: _HostRequestStatus.ValueType  # 3
    HOST_REQUEST_STATUS_CANCELLED: _HostRequestStatus.ValueType  # 4

class HostRequestStatus(_HostRequestStatus, metaclass=_HostRequestStatusEnumTypeWrapper): ...

HOST_REQUEST_STATUS_PENDING: HostRequestStatus.ValueType  # 0
HOST_REQUEST_STATUS_ACCEPTED: HostRequestStatus.ValueType  # 1
HOST_REQUEST_STATUS_REJECTED: HostRequestStatus.ValueType  # 2
HOST_REQUEST_STATUS_CONFIRMED: HostRequestStatus.ValueType  # 3
HOST_REQUEST_STATUS_CANCELLED: HostRequestStatus.ValueType  # 4
Global___HostRequestStatus: typing_extensions.TypeAlias = HostRequestStatus

@typing.final
class MessageContentText(google.protobuf.message.Message):
    """Shared conversation types used by multiple services (conversations, requests).
    These live in their own leaf file (no couchers imports) so that any service
    can reference them without creating circular proto imports.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    text: builtins.str
    """plain text"""
    def __init__(
        self,
        *,
        text: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["text", b"text"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___MessageContentText: typing_extensions.TypeAlias = MessageContentText

@typing.final
class MessageContentChatCreated(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___MessageContentChatCreated: typing_extensions.TypeAlias = MessageContentChatCreated

@typing.final
class MessageContentChatEdited(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___MessageContentChatEdited: typing_extensions.TypeAlias = MessageContentChatEdited

@typing.final
class MessageContentUserInvited(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARGET_USER_ID_FIELD_NUMBER: builtins.int
    target_user_id: builtins.int
    def __init__(
        self,
        *,
        target_user_id: builtins.int | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["target_user_id", b"target_user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___MessageContentUserInvited: typing_extensions.TypeAlias = MessageContentUserInvited

@typing.final
class MessageContentUserLeft(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___MessageContentUserLeft: typing_extensions.TypeAlias = MessageContentUserLeft

@typing.final
class MessageContentUserMadeAdmin(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARGET_USER_ID_FIELD_NUMBER: builtins.int
    target_user_id: builtins.int
    def __init__(
        self,
        *,
        target_user_id: builtins.int | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["target_user_id", b"target_user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___MessageContentUserMadeAdmin: typing_extensions.TypeAlias = MessageContentUserMadeAdmin

@typing.final
class MessageContentUserRemovedAdmin(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARGET_USER_ID_FIELD_NUMBER: builtins.int
    target_user_id: builtins.int
    def __init__(
        self,
        *,
        target_user_id: builtins.int | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["target_user_id", b"target_user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___MessageContentUserRemovedAdmin: typing_extensions.TypeAlias = MessageContentUserRemovedAdmin

@typing.final
class MessageContentUserRemoved(google.protobuf.message.Message):
    """field in Message, when a user is removed by admin"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARGET_USER_ID_FIELD_NUMBER: builtins.int
    target_user_id: builtins.int
    def __init__(
        self,
        *,
        target_user_id: builtins.int | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["target_user_id", b"target_user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___MessageContentUserRemoved: typing_extensions.TypeAlias = MessageContentUserRemoved

@typing.final
class MessageContentHostRequestStatusChanged(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: Global___HostRequestStatus.ValueType
    """this is the new host request status"""
    def __init__(
        self,
        *,
        status: Global___HostRequestStatus.ValueType | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["status", b"status"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___MessageContentHostRequestStatusChanged: typing_extensions.TypeAlias = MessageContentHostRequestStatusChanged

@typing.final
class Message(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGE_ID_FIELD_NUMBER: builtins.int
    AUTHOR_USER_ID_FIELD_NUMBER: builtins.int
    TIME_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    CHAT_CREATED_FIELD_NUMBER: builtins.int
    CHAT_EDITED_FIELD_NUMBER: builtins.int
    USER_INVITED_FIELD_NUMBER: builtins.int
    USER_LEFT_FIELD_NUMBER: builtins.int
    USER_MADE_ADMIN_FIELD_NUMBER: builtins.int
    USER_REMOVED_ADMIN_FIELD_NUMBER: builtins.int
    HOST_REQUEST_STATUS_CHANGED_FIELD_NUMBER: builtins.int
    GROUP_CHAT_USER_REMOVED_FIELD_NUMBER: builtins.int
    message_id: builtins.int
    author_user_id: builtins.int
    @property
    def time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def text(self) -> Global___MessageContentText:
        """plain text"""

    @property
    def chat_created(self) -> Global___MessageContentChatCreated: ...
    @property
    def chat_edited(self) -> Global___MessageContentChatEdited: ...
    @property
    def user_invited(self) -> Global___MessageContentUserInvited: ...
    @property
    def user_left(self) -> Global___MessageContentUserLeft: ...
    @property
    def user_made_admin(self) -> Global___MessageContentUserMadeAdmin: ...
    @property
    def user_removed_admin(self) -> Global___MessageContentUserRemovedAdmin: ...
    @property
    def host_request_status_changed(self) -> Global___MessageContentHostRequestStatusChanged: ...
    @property
    def group_chat_user_removed(self) -> Global___MessageContentUserRemoved:
        """user removed by admin"""

    def __init__(
        self,
        *,
        message_id: builtins.int | None = ...,
        author_user_id: builtins.int | None = ...,
        time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        text: Global___MessageContentText | None = ...,
        chat_created: Global___MessageContentChatCreated | None = ...,
        chat_edited: Global___MessageContentChatEdited | None = ...,
        user_invited: Global___MessageContentUserInvited | None = ...,
        user_left: Global___MessageContentUserLeft | None = ...,
        user_made_admin: Global___MessageContentUserMadeAdmin | None = ...,
        user_removed_admin: Global___MessageContentUserRemovedAdmin | None = ...,
        host_request_status_changed: Global___MessageContentHostRequestStatusChanged | None = ...,
        group_chat_user_removed: Global___MessageContentUserRemoved | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["chat_created", b"chat_created", "chat_edited", b"chat_edited", "content", b"content", "group_chat_user_removed", b"group_chat_user_removed", "host_request_status_changed", b"host_request_status_changed", "text", b"text", "time", b"time", "user_invited", b"user_invited", "user_left", b"user_left", "user_made_admin", b"user_made_admin", "user_removed_admin", b"user_removed_admin"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["author_user_id", b"author_user_id", "chat_created", b"chat_created", "chat_edited", b"chat_edited", "content", b"content", "group_chat_user_removed", b"group_chat_user_removed", "host_request_status_changed", b"host_request_status_changed", "message_id", b"message_id", "text", b"text", "time", b"time", "user_invited", b"user_invited", "user_left", b"user_left", "user_made_admin", b"user_made_admin", "user_removed_admin", b"user_removed_admin"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType_content: typing_extensions.TypeAlias = typing.Literal["text", "chat_created", "chat_edited", "user_invited", "user_left", "user_made_admin", "user_removed_admin", "host_request_status_changed", "group_chat_user_removed"]
    _WhichOneofArgType_content: typing_extensions.TypeAlias = typing.Literal["content", b"content"]
    def WhichOneof(self, oneof_group: _WhichOneofArgType_content) -> _WhichOneofReturnType_content | None: ...

Global___Message: typing_extensions.TypeAlias = Message



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: annotations.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x61nnotations.proto\x1a google/protobuf/descriptor.proto\"o\n\tRateLimit\x12\x13\n\x06per_ip\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x15\n\x08per_user\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06global\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\t\n\x07_per_ipB\x0b\n\t_per_userB\t\n\x07_global*\x93\x01\n\tAuthLevel\x12\x16\n\x12\x41UTH_LEVEL_UNKNOWN\x10\x00\x12\x13\n\x0f\x41UTH_LEVEL_OPEN\x10\x01\x12\x15\n\x11\x41UTH_LEVEL_JAILED\x10\x02\x12\x15\n\x11\x41UTH_LEVEL_SECURE\x10\x03\x12\x15\n\x11\x41UTH_LEVEL_EDITOR\x10\x05\x12\x14\n\x10\x41UTH_LEVEL_ADMIN\x10\x04:2\n\tsensitive\x12\x1d.google.protobuf.FieldOptions\x18\xd0\x86\x03 \x01(\x08:1\n\x08is_token\x12\x1d.google.protobuf.FieldOptions\x18\xd1\x86\x03 \x01(\x08:A\n\nauth_level\x12\x1f.google.protobuf.ServiceOptions\x18\xd1\x86\x03 \x01(\x0e\x32\n.AuthLevel:I\n\x12rate_limit_default\x12\x1f.google.protobuf.ServiceOptions\x18\xd3\x86\x03 \x01(\x0b\x32\n.RateLimit:K\n\x14rate_limit_aggregate\x12\x1f.google.protobuf.ServiceOptions\x18\xd4\x86\x03 \x01(\x0b\x32\n.RateLimit:@\n\nrate_limit\x12\x1e.google.protobuf.MethodOptions\x18\xd2\x86\x03 \x01(\x0b\x32\n.RateLimitb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'annotations_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_AUTHLEVEL']._serialized_start=169
  _globals['_AUTHLEVEL']._serialized_end=316
  _globals['_RATELIMIT']._serialized_start=55
  _globals['_RATELIMIT']._serialized_end=166
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.descriptor_pb2
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.internal.extension_dict
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _AuthLevel:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AuthLevelEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AuthLevel.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    AUTH_LEVEL_UNKNOWN: _AuthLevel.ValueType  # 0
    """error"""
    AUTH_LEVEL_OPEN: _AuthLevel.ValueType  # 1
    """accessible to all"""
    AUTH_LEVEL_JAILED: _AuthLevel.ValueType  # 2
    """accessible to users who need to finish some things to get into the app"""
    AUTH_LEVEL_SECURE: _AuthLevel.ValueType  # 3
    """accessible to all signed in users"""
    AUTH_LEVEL_EDITOR: _AuthLevel.ValueType  # 5
    """accessible to editors (admin-lite: can create communities, modify volunteer data)"""
    AUTH_LEVEL_ADMIN: _AuthLevel.ValueType  # 4
    """accessible only by the Couchers organization"""

class AuthLevel(_AuthLevel, metaclass=_AuthLevelEnumTypeWrapper): ...

AUTH_LEVEL_UNKNOWN: AuthLevel.ValueType  # 0
"""error"""
AUTH_LEVEL_OPEN: AuthLevel.ValueType  # 1
"""accessible to all"""
AUTH_LEVEL_JAILED: AuthLevel.ValueType  # 2
"""accessible to users who need to finish some things to get into the app"""
AUTH_LEVEL_SECURE: AuthLevel.ValueType  # 3
"""accessible to all signed in users"""
AUTH_LEVEL_EDITOR: AuthLevel.ValueType  # 5
"""accessible to editors (admin-lite: can create communities, modify volunteer data)"""
AUTH_LEVEL_ADMIN: AuthLevel.ValueType  # 4
"""accessible only by the Couchers organization"""
Global___AuthLevel: typing_extensions.TypeAlias = AuthLevel

@typing.final
class RateLimit(google.protobuf.message.Message):
    """A rate limit, in requests per minute, with one optional count per dimension. Unset fields fall back
    to the service default (per-RPC) or a global default constant. See docs/rate-limit-design.md.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PER_IP_FIELD_NUMBER: builtins.int
    PER_USER_FIELD_NUMBER: builtins.int
    GLOBAL_FIELD_NUMBER: builtins.int
    per_ip: builtins.int
    per_user: builtins.int
    def __init__(
        self,
        *,
        per_ip: builtins.int | None = ...,
        per_user: builtins.int | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["_global", b"_global", "_per_ip", b"_per_ip", "_per_user", b"_per_user", "global", b"global", "per_ip", b"per_ip", "per_user", b"per_user"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["_global", b"_global", "_per_ip", b"_per_ip", "_per_user", b"_per_user", "global", b"global", "per_ip", b"per_ip", "per_user", b"per_user"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType__global: typing_extensions.TypeAlias = typing.Literal["global"]
    _WhichOneofArgType__global: typing_extensions.TypeAlias = typing.Literal["_global", b"_global"]
    _WhichOneofReturnType__per_ip: typing_extensions.TypeAlias = typing.Literal["per_ip"]
    _WhichOneofArgType__per_ip: typing_extensions.TypeAlias = typing.Literal["_per_ip", b"_per_ip"]
    _WhichOneofReturnType__per_user: typing_extensions.TypeAlias = typing.Literal["per_user"]
    _WhichOneofArgType__per_user: typing_extensions.TypeAlias = typing.Literal["_per_user", b"_per_user"]
    @typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__global) -> _WhichOneofReturnType__global | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__per_ip) -> _WhichOneofReturnType__per_ip | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__per_user) -> _WhichOneofReturnType__per_user | None: ...

Global___RateLimit: typing_extensions.TypeAlias = RateLimit

SENSITIVE_FIELD_NUMBER: builtins.int
IS_TOKEN_FIELD_NUMBER: builtins.int
AUTH_LEVEL_FIELD_NUMBER: builtins.int
RATE_LIMIT_DEFAULT_FIELD_NUMBER: builtins.int
RATE_LIMIT_AGGREGATE_FIELD_NUMBER: builtins.int
RATE_LIMIT_FIELD_NUMBER: builtins.int
sensitive: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.bool]
"""whether the field is sensitive and should not be logged"""
is_token: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.bool]
"""this is a token"""
auth_level: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.ServiceOptions, Global___AuthLevel.ValueType]
"""the auth level required to access this service, one of"""
rate_limit_default: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.ServiceOptions, Global___RateLimit]
"""default per-RPC rate limit applied to every method in this service"""
rate_limit_aggregate: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.ServiceOptions, Global___RateLimit]
"""per-servicer aggregate rate limit, counting all methods in this service together"""
rate_limit: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MethodOptions, Global___RateLimit]
"""this method's per-RPC rate limit, overriding the service default"""
